//---------------------------------------------------------------------------
// File  :  FFP_framework.h
// Date  :  2007-03-02   (YYYY-MM-DD)
// Author:  Wolfgang Buescher  (DL4YHF)
// Location: <DL4YHF>C:\cbproj\SpecLab\fft_filter_plugins\*.*
//
// Description:
//   Some framework for FFT-filter-plugins with their own GUI .
//   Creates a small control window without a message loop (non-blocking !).
//   Compile with Dev-Cpp or Borland C++ Builder V4;
//           MS-C may work but never tested.
//

#ifndef CPROT   /* kludge for mixed C / C++ usage */
// Note on "extern": One of Borland's examples is wrong..
//   >extern "c" = nonsense (not recognized by Borland C++ V4.0)
//   >extern "C" = correct  (though the help system says something different)
#ifdef __cplusplus
 #define CPROT extern "C"
#else
 #define CPROT
#endif  /* ! "cplusplus" */
#endif


//---------------------------------------------------------------------------
// Defines
//---------------------------------------------------------------------------
#ifndef  C_PI
 #define C_PI  (3.1415926535897932384626)
#endif



//---------------------------------------------------------------------------
// Variables
//---------------------------------------------------------------------------
extern int FFPFW_iDllInstanceCount; // instance counter of the DLL .
    // Incremented in the DLL main entry point on 'DLL_PROCESS_ATTACH',
    // decremented on 'DLL_PROCESS_DETACH'. Required to unregister window.

  // "Calibration" parameters, may be set to the actual values
  // used in Spectrum Lab, i.e. copied from T_FftFilterInfo->dblAdcMaxInputVoltage
  // to use these values in subroutines which cannot access that structure .
extern double FFP_dblAdcMaxInputVoltage; // max ADC input voltage [Volts] at the clipping point
extern double FFP_dblAdcInputImpedance; // input impedance [Ohms, default = 50] 

//---------------------------------------------------------------------------
// Functions which must be implemented in the plugin,
//   called by the event handler (in FFP_frameworkX.c)
//---------------------------------------------------------------------------
CPROT int FFP_OnKeyDown( T_FftFilterInfo *pInfo, int nVirtKey, long lKeyData );
  // Called from FFP_frameworkX on reception of the WM_KEYDOWN message .
  // nVirtKey : Specifies the virtual-key code of the nonsystem key.
  //            In many cases, this is simply the key's ASCII code,
  //            or one of the VK_....-values defined in WINUSER.H .
  // lKeyData : Specifies the repeat count, scan code, extended-key flag,
  //            context code, previous key-state flag, and transition-state flag,
  //            as shown in the Win32 programmer's reference on "WM_KEYDOWN" .
  // The application should return zero if it processes this message .


//---------------------------------------------------------------------------
// Functions implemented in the framework" module (FFP_frameworkX.c)
//---------------------------------------------------------------------------
CPROT BOOL FFP_OpenControlPanel( // opens an own "control window" for the plugin
   T_FftFilterInfo *pInfo, // plugin into, contains handle to application instance
   char *pszWindowTitle);  // text which appears in the window title
CPROT void FFP_CloseControlPanel(T_FftFilterInfo *pInfo);
CPROT void FFP_DestroyControlPanel(T_FftFilterInfo *pInfo);
CPROT void FFP_UnregisterWndClassIfLastDllInstance(T_FftFilterInfo *pInfo);

//---------------------------------------------------------------------------
//  Helper functions for FFP_OnDrawSpectrum(), details in FFP_framework1.c
//---------------------------------------------------------------------------
CPROT BOOL FFP_DrawSpectrum_CheckCompatibility(
        T_FFP_SPECTRUM_DRAWING_INFO *pDrawingInfo);
CPROT BOOL FFP_DrawSpectrum_FreqAndAmplitudeToScreenPos(
        T_FFP_SPECTRUM_DRAWING_INFO *pDrawingInfo,
        double dblFrequency, double dblAmpl, int iAmplScaleUnit, int *piX, int *piY );


/* EOF <FFP_framework.h> */
